#include "maze.h"

// Engine includes.
#include "Cell.h"
#include "LogManager.h"
#include "Vector.h"
#include "WorldManager.h"

void Cell::init(int init_row, int init_col) {
  for (int i=0; i<4; i++)
    wall[i] = true;
  row = init_row;
  col = init_col;
  df::Vector p1(col*COL_WIDTH, row*ROW_WIDTH+1);
  p_west_wall = new WallVertical(p1);
  df::Vector p2(col*COL_WIDTH+1, row*ROW_WIDTH+1);
  p_south_wall = new WallHorizontal(p2);
}

void Cell::removeWall(enum wall_enum w) {
  if (w!=WALL_NORTH && w!=WALL_EAST && w!=WALL_SOUTH && w!=WALL_WEST) {
    df::LogManager &log_manager = df::LogManager::getInstance();
    log_manager.writeLog("Cell::removeWall():  Illegal wall %d!\n", w);
    return;
  }

  wall[w] = false;

  if (w == WALL_WEST) {
    df::WorldManager &world_manager = df::WorldManager::getInstance();
    world_manager.markForDelete(p_west_wall);
  }
  if (w == WALL_SOUTH) {
    df::WorldManager &world_manager = df::WorldManager::getInstance();
    world_manager.markForDelete(p_south_wall);
  }

}

int Cell::getRow() {
  return row;
}

int Cell::getCol() {
  return col;
}

bool Cell::fourWalls() {
  if (wall[0] && wall[1] && wall[2] && wall[3])
    return true;
  else
    return false;
}



